@@ -1,6 +1,6 @@
 # Mail::Alias.pm
 #
-# Version 1.13 		Date: 26 February 2022
+# Version 1.15 		Date: 26 February 2022
 #
 # Copyright (c) 2022 Jonathan Kamens <jik@kamens.us>. All rights reserved.
 # This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@ package Mail::Alias;             #
 use Carp;
 use vars qw($VERSION);
 
-$VERSION = 1.13;
+$VERSION = 1.15;
 sub Version { $VERSION }
 
 
@@ -532,12 +532,12 @@ sub write {
 #-----------------------------------------------------------#
 sub _include_file {
  my $file = shift;
- local *INC;
+ local *INCLUDE;
  my @ln;
  local $_;
- open(INC,$file) or carp "Cannot open file '$file'" and return "";
- @ln = grep(/^[^#]/,<INC>);
- close(INC);
+ open(INCLUDE,$file) or carp "Cannot open file '$file'" and return "";
+ @ln = grep(/^[^#]/,<INCLUDE>);
+ close(INCLUDE);
  chomp(@ln);
  join(",",@ln);
 }
@@ -556,18 +556,20 @@ sub read {
  my $group = undef;
  my $line = undef;
 
- while(<ALIAS>) {
-  chomp;
-  if(defined $line && /^\s/) {		
-   $line .= $_;
+ while(defined($_ = <ALIAS>) or defined($line)) {
+  if(defined $_) {
+   chomp;
+   if(defined $line && /^\s/) {		
+    $line .= $_;
+    next;
+   }
   }
-  else {
-   if(defined $line) {
+  if(defined $line) {
     if($line =~ s/^([^:]+)://) {	
      my @resp;
      $group = $1;
      $group =~ s/(\A\s+|\s+\Z)//g;	
-     $line =~ s/\"?:include:(\S+)\"?/_include_file($1)/eg;	
+     $line =~ s/\"?:include:\s*(\S+)\"?/_include_file($1)/eg;	
      $line =~ s/(\A[\s,]+|[\s,]+\Z)//g;
 
      while(length($line)) {
@@ -578,10 +580,10 @@ sub read {
      $me->{$group} = \@resp;
     }
     undef $line;
-   }
-   next if (/^#/ || /^\s*$/);		
-   $line = $_;
   }
+  last if (! defined $_);
+  next if (/^#/ || /^\s*$/);		
+  $line = $_;
  }
  close(ALIAS);
 }
